@@ -2,11 +2,40 @@ import secrets
 import string
 import typing
 
-from terminusgps.wialon import flags, items
-from terminusgps.wialon.items.base import WialonBase
+from terminusgps.wialon import constants, flags
 from terminusgps.wialon.session import WialonSession
 
 
+def get_resource_ids(session: WialonSession) -> list[int] | None:
+    """
+    Returns a list of all resource ids in Wialon.
+
+    :param session: A valid Wialon API session.
+    :type session: :py:obj:`~terminusgps.wialon.session.WialonSession`
+    :returns: A list of account ids.
+    :rtype: :py:obj:`list`
+
+    """
+    results = session.wialon_api.core_search_items(
+        **{
+            "spec": {
+                "itemsType": "avl_resource",
+                "propName": "sys_id",
+                "propValueMask": "*",
+                "sortType": "sys_id",
+                "propType": "property",
+                "or_logic": False,
+            },
+            "force": 0,
+            "flags": 1,
+            "from": 0,
+            "to": 0,
+        }
+    )
+    if results:
+        return [int(item.get("id")) for item in results.get("items", [])]
+
+
 def get_hw_type_id(name: str, session: WialonSession) -> int | None:
     """
     Takes a Wialon hardware type name and returns its id, if it exists.
@@ -49,7 +78,7 @@ def get_id_from_imei(imei: str, session: WialonSession) -> str | None:
     if not imei.isdigit():
         raise ValueError(f"'imei' must be a digit, got '{imei}'.")
 
-    results = session.wialon_api.core_search_items(
+    results: dict[str, typing.Any] | None = session.wialon_api.core_search_items(
         **{
             "spec": {
                 "itemsType": "avl_unit",
@@ -60,57 +89,16 @@ def get_id_from_imei(imei: str, session: WialonSession) -> str | None:
                 "or_logic": 0,
             },
             "force": 0,
-            "flags": flags.DATAFLAG_UNIT_BASE,
+            "flags": flags.DataFlag.UNIT_BASE.value,
             "from": 0,
             "to": 0,
         }
     )
 
-    if results.get("totalItemsCount", 0) == 1:
+    if results and results.get("totalItemsCount", 0) == 1:
         return results["items"][0].get("id")
 
 
-def get_id_from_iccid(iccid: str, session: WialonSession) -> str | None:
-    """
-    DEPRECATED: Use :py:func:`~terminusgps.wialon.utils.get_id_from_imei`.
-
-    Takes a Wialon unit's IMEI # and returns its unit id, if it exists.
-
-    :param iccid: A unique id.
-    :type iccid: :py:obj:`str`
-    :param session: A valid Wialon API session.
-    :type session: :py:obj:`~terminusgps.wialon.session.WialonSession`
-    :raises WialonError: If something goes wrong during a Wialon API call.
-    :returns: A Wialon object id, if it was found.
-    :rtype: :py:obj:`str` | :py:obj:`None`
-
-    """
-    return get_id_from_imei(imei=iccid, session=session)
-
-
-def get_wialon_cls(items_type: str) -> typing.Type[WialonBase]:
-    """
-    Returns a Wialon object class based on items_type.
-
-    :param items_type: A Wialon object type.
-    :type items_type: :py:obj:`str`
-    :returns: A subclass of :py:obj:`~terminusgps.wialon.items.base.WialonBase`.
-    :rtype: :py:obj:`~terminusgps.wialon.items.base.WialonBase`
-
-    """
-    match items_type:
-        case "user":
-            return items.WialonUser
-        case "avl_unit":
-            return items.WialonUnit
-        case "avl_unit_group":
-            return items.WialonUnitGroup
-        case "avl_resource":
-            return items.WialonResource
-        case _:
-            raise ValueError(f"Invalid items_type, got '{items_type}'.")
-
-
 def get_vin_info(vin_number: str, session: WialonSession) -> dict:
     """
     Retrieves vehicle data from a VIN number.
@@ -123,17 +111,24 @@ def get_vin_info(vin_number: str, session: WialonSession) -> dict:
     :rtype: :py:obj:`dict`
 
     """
-    response = session.wialon_api.unit_get_vin_info(**{"vin": vin_number}).get(
-        "vin_lookup_result"
-    )
-    return (
-        {field.get("n"): field.get("v") for field in response.get("pflds")}
-        if "error" not in response.keys()
-        else {}
+    response: dict[str, typing.Any] | None = session.wialon_api.unit_get_vin_info(
+        **{"vin": vin_number}
     )
 
+    if response is None or "error" in response.get("vin_lookup_result", {}).keys():
+        return {}
 
-def is_unique(value: str, session: WialonSession, items_type: str = "avl_unit") -> bool:
+    return {
+        field.get("n"): field.get("v")
+        for field in response.get("vin_lookup_result", {}).get("pflds")
+    }
+
+
+def is_unique(
+    value: str,
+    session: WialonSession,
+    items_type: str = constants.WialonItemsType.UNIT.value,
+) -> bool:
     """
     Determines if the value is unique among Wialon objects of type 'items_type'.
 
@@ -148,11 +143,10 @@ def is_unique(value: str, session: WialonSession, items_type: str = "avl_unit")
     :rtype: :py:obj:`bool`
 
     """
-    return not bool(
-        session.wialon_api.core_check_unique(
-            **{"type": items_type, "value": value.strip()}
-        ).get("result")
+    response = session.wialon_api.core_check_unique(
+        **{"type": items_type, "value": value.strip()}
     )
+    return not bool(response.get("result")) if response else False
 
 
 def generate_wialon_password(length: int = 32) -> str:
